@@ -8,15 +8,7 @@
 *
 ********************************************************************************
 *
-* $Project: /Convert-Binary-C $
-* $Author: mhx $
-* $Date: 2011/04/10 12:32:17 +0200 $
-* $Revision: 26 $
-* $Source: /ctlib/byteorder.c $
-*
-********************************************************************************
-*
-* Copyright (c) 2002-2011 Marcus Holland-Moritz. All rights reserved.
+* Copyright (c) 2002-2024 Marcus Holland-Moritz. All rights reserved.
 * This program is free software; you can redistribute it and/or modify
 * it under the same terms as Perl itself.
 *
@@ -27,6 +19,10 @@
 #include <ctype.h>
 #include <assert.h>
 
+#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
+#include <stdint.h>
+#endif
+
 
 /*===== LOCAL INCLUDES =======================================================*/
 
@@ -39,6 +35,12 @@
 #define NULL ((void *) 0)
 #endif
 
+#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
+typedef uintptr_t uintptr_type;
+#else
+typedef unsigned long uintptr_type;
+#endif
+
 /*----------------------------------------------------------*/
 /* reading/writing integers in big/little endian byte order */
 /* depending on the native byte order of the system         */
@@ -145,7 +147,7 @@
 
 #define GET_BE_WORD(ptr, value, sign)                                          \
           do {                                                                 \
-            if (((unsigned long) (ptr)) % 2)                                   \
+            if (((uintptr_type) (ptr)) % 2)                                    \
               value = (sign ## _16)                                            \
                       ( ( (u_16) *( (const u_8 *) ((ptr)+0) ) <<  8)           \
                       | ( (u_16) *( (const u_8 *) ((ptr)+1) ) <<  0)           \
@@ -156,7 +158,7 @@
 
 #define GET_BE_LONG(ptr, value, sign)                                          \
           do {                                                                 \
-            switch (((unsigned long) (ptr)) % 4)                               \
+            switch (((uintptr_type) (ptr)) % 4)                                \
             {                                                                  \
               case 0:                                                          \
                 value = (sign ## _32) ( *( (const u_32 *) (ptr) ) );           \
@@ -199,7 +201,7 @@
 
 #define SET_BE_WORD(ptr, value)                                                \
           do {                                                                 \
-            if (((unsigned long) (ptr)) % 2)                                   \
+            if (((uintptr_type) (ptr)) % 2)                                    \
             {                                                                  \
               register u_16 v = (u_16) value;                                  \
               *((u_8 *) ((ptr)+0)) = (u_8) ((v >> 8) & 0xFF);                  \
@@ -211,7 +213,7 @@
 
 #define SET_BE_LONG(ptr, value)                                                \
           do {                                                                 \
-            switch (((unsigned long) (ptr)) % 4)                               \
+            switch (((uintptr_type) (ptr)) % 4)                                \
             {                                                                  \
               case 0:                                                          \
                 *( (u_32 *) (ptr) ) = (u_32) value;                            \
@@ -356,7 +358,7 @@
 
 #define GET_LE_WORD(ptr, value, sign)                                          \
           do {                                                                 \
-            if (((unsigned long) (ptr)) % 2)                                   \
+            if (((uintptr_type) (ptr)) % 2)                                    \
               value = (sign ## _16)                                            \
                       ( ( (u_16) *( (const u_8 *) ((ptr)+0) ) <<  0)           \
                       | ( (u_16) *( (const u_8 *) ((ptr)+1) ) <<  8)           \
@@ -367,7 +369,7 @@
 
 #define GET_LE_LONG(ptr, value, sign)                                          \
           do {                                                                 \
-            switch (((unsigned long) (ptr)) % 4)                               \
+            switch (((uintptr_type) (ptr)) % 4)                                \
             {                                                                  \
               case 0:                                                          \
                 value = (sign ## _32) ( *( (const u_32 *) (ptr) ) );           \
@@ -410,7 +412,7 @@
 
 #define SET_LE_WORD(ptr, value)                                                \
           do {                                                                 \
-            if (((unsigned long) (ptr)) % 2)                                   \
+            if (((uintptr_type) (ptr)) % 2)                                    \
             {                                                                  \
               register u_16 v = (u_16) value;                                  \
               *((u_8 *) ((ptr)+0)) = (u_8) ((v >> 0) & 0xFF);                  \
@@ -422,7 +424,7 @@
 
 #define SET_LE_LONG(ptr, value)                                                \
           do {                                                                 \
-            switch (((unsigned long) (ptr)) % 4)                               \
+            switch (((uintptr_type) (ptr)) % 4)                                \
             {                                                                  \
               case 0:                                                          \
                 *( (u_32 *) (ptr) ) = (u_32) value;                            \
