@@ -8,25 +8,9 @@
 *
 ********************************************************************************
 *
-* $Project: /Convert-Binary-C $
-* $Author: mhx $
-* $Date: 2011/04/10 12:32:31 +0200 $
-* $Revision: 29 $
-* $Source: /util/memalloc.h $
-*
-********************************************************************************
-*
-* Copyright (c) 2002-2011 Marcus Holland-Moritz. All rights reserved.
-*
-* This program is free software; you can redistribute it and/or
-* modify it under the terms of either the Artistic License or the
-* GNU General Public License as published by the Free Software
-* Foundation; either version 2 of the License, or (at your option)
-* any later version.
-*
-* THIS PROGRAM IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR
-* IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
-* WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+* Copyright (c) 2002-2024 Marcus Holland-Moritz. All rights reserved.
+* This program is free software; you can redistribute it and/or modify
+* it under the same terms as Perl itself.
 *
 *******************************************************************************/
 
@@ -353,8 +337,10 @@ int SetDebugMemAlloc( void (*dbfunc)(char *, ...), unsigned long dbflags );
 #ifdef ABORT_IF_NO_MEM
 # define abortMEMALLOC( call, size, expr )                                     \
         do {                                                                   \
-          if( (expr) == NULL && size > 0 ) {                                   \
-            fprintf(stderr, "%s(%d): out of memory!\n", call, size);           \
+          size_t tmp_size__ = (size);                                          \
+          if( (expr) == NULL && tmp_size__ > 0 ) {                             \
+            fprintf(stderr, "%s(%u): out of memory!\n",                        \
+                    call, (unsigned) tmp_size__);                              \
             abort();                                                           \
           }                                                                    \
         } while(0)
